# Changelog

All notable changes to this project will be documented in this file.

## Unreleased

- Documentation updates and SDK usage examples.

## 0.1.0 - 2026-01-21

- Initial release with core ad selection and injection helpers.
